{config, ...}: {
  home-manager.users.jade = {pkgs, ...}: {
    home = {
      sessionVariables.EDITOR = "hx";
      packages = [
        pkgs.nil
        pkgs.vscode-langservers-extracted
        pkgs.nodePackages.typescript-language-server
        pkgs.emmet-language-server
      ];
    };
    programs.helix = {
      enable = true;
      settings = {
        theme = "gruvbox";
        editor = {
          line-number = "relative";
          lsp.display-messages = true;
          indent-guides = {
            render = true;
            character = "│";
          };
          whitespace = {
            render = {
              space = "all";
              tab = "all";
              newline = "none";
            };
            characters = {
              space = "·";
              nbsp = "⍽";
              tab = "→";
            };
          };
        };
        keys.normal = {
          space."=" = ":fmt";
        };
      };
      languages = {
        language-server."nu-builtin-lsp" = {
          command = "${config.users.defaultUserShell}/bin/nu";
          args = ["--lsp"];
        };
        language-server."rust-analyzer" = {
          config = {
            check.command = "clippy";
          };
        };
        language-server."emmet-language-server" = {
          command = "emmet-language-server";
          args = ["--stdio"];
        };
        # "php" = {
        #   name = "php";
        #   file-types = [ "php" ];
        #   language-server = {
        #     command = "psalm";
        #     args = ["--language-server"];
        #   };
        # };
        language = [
          {
            name = "nu";
            language-servers = ["nu-builtin-lsp"];
          }
          {
            name = "nix";
            formatter = {
              command = "${pkgs.alejandra}/bin/alejandra";
              args = ["--quiet"];
            };
            auto-format = true;
          }
          {
            name = "html";
            roots = [".git"];
            language-servers = ["emmet-language-server" "vscode-html-language-server"];
          }
        ];
      };
    };
  };
}
